import React from 'react';
import { Toast as HotToastProps } from 'react-hot-toast/dist/core/types';
export interface ToastProps extends Partial<HotToastProps> {
    description?: string;
    closable?: boolean;
    actions?: React.ReactNode;
    actionsPosition?: 'inline' | 'bottom';
    width?: 'xs' | 'sm' | 'md';
}
/**
 * react-hot-toast is used under-the-hood and is a required dependency.
 *
 * Add `<Toast.Toaster />` to your app or wrap it around your components `<Toast.Toaster><Components /></Toast.Toaster>`
 *
 * You can also just use react-hot-toast's `toast` for basic toasts:
 *
 * `toast.success('Complete!')`
 *
 *  For the extra features you need to use the `Toast.toast` wrapper:
 *
 * `Toast.toast('Message', { description: 'Description', actions: [<SomeButton />] })`
 */
declare function Toast({ id, visible, type, icon, description, closable, actions, actionsPosition, message, width, ...rest }: ToastProps): JSX.Element;
declare namespace Toast {
    var Toaster: ({ children }: ToasterProps) => JSX.Element;
    var toast: typeof import("./Toast").toast;
}
interface ToasterProps {
    children?: React.ReactNode;
}
declare type ToastOptions = Partial<Pick<ToastProps, 'id' | 'icon' | 'duration' | 'position' | 'ariaProps' | 'style' | 'className' | 'iconTheme' | 'type' | 'description' | 'closable' | 'actions' | 'actionsPosition'>>;
export declare function toast(message: string, opts?: ToastOptions): string;
export declare namespace toast {
    var success: (message: string, opts?: Omit<Partial<Pick<ToastProps, "className" | "id" | "style" | "closable" | "icon" | "type" | "description" | "actions" | "duration" | "position" | "ariaProps" | "iconTheme" | "actionsPosition">>, "type"> | undefined) => string;
    var error: (message: string, opts?: Omit<Partial<Pick<ToastProps, "className" | "id" | "style" | "closable" | "icon" | "type" | "description" | "actions" | "duration" | "position" | "ariaProps" | "iconTheme" | "actionsPosition">>, "type"> | undefined) => string;
    var loading: (message: string, opts?: Omit<Partial<Pick<ToastProps, "className" | "id" | "style" | "closable" | "icon" | "type" | "description" | "actions" | "duration" | "position" | "ariaProps" | "iconTheme" | "actionsPosition">>, "type"> | undefined) => string;
    var promise: (promise: Promise<unknown>, msgs: {
        loading: import("react-hot-toast/dist/core/types").Renderable;
        success: import("react-hot-toast/dist/core/types").ValueOrFunction<import("react-hot-toast/dist/core/types").Renderable, unknown>;
        error: import("react-hot-toast/dist/core/types").ValueOrFunction<import("react-hot-toast/dist/core/types").Renderable, any>;
    }, opts?: import("react-hot-toast/dist/core/types").DefaultToastOptions | undefined) => Promise<unknown>;
}
export default Toast;
